@@ -316,9 +316,18 @@ class RDSClient():
                                  aut: float):
         """
         """
-        query = f"INSERT INTO neuralplatform_classperformance(model_id, classDefinition_id, accByAut, minConfidence, automatization) VALUES({model_id}, {class_id}, {json.dumps(acc_by_aut)}, {conf}, {aut});"
+        query = f"INSERT INTO neuralplatform_classperformance(model_id, classDefinition_id, accByAut, minConfidence, automatization) VALUES({model_id}, {class_id}, '{json.dumps(acc_by_aut)}', {conf}, {aut});"
         return self.insert_query(query)
     
+    def get_version_confidences(self,
+                                version_id: int) -> dict:
+        """
+        """
+        query = f"SELECT id FROM neuralplatform_model WHERE version_id = {version_id};"
+        model_id = self.select_query(query, fetchone=True) ['id']
+        query = f"SELECT classDefinition_id, minConfidence FROM neuralplatform_classperformance WHERE model_id = {model_id};"
+        return { r['classDefinition_id'] : r['minConfidence'] for r in self.select_query(query, fetchone=False) }
+    
     ## Automlapi functions
     def get_pending_and_unblocked_steps(self):
         """
